EXPORTS
	??0CMmfGlobalAudioEffect@@IAE@XZ @ 1 NONAME ; CMmfGlobalAudioEffect::CMmfGlobalAudioEffect(void)
	??1CMmfGlobalAudioEffect@@UAE@XZ @ 2 NONAME ; CMmfGlobalAudioEffect::~CMmfGlobalAudioEffect(void)
	?BaseConstructL@CMmfGlobalAudioEffect@@IAEXVTUid@@PAVMMmfGlobalAudioEffectObserver@@@Z @ 3 NONAME ; void CMmfGlobalAudioEffect::BaseConstructL(class TUid, class MMmfGlobalAudioEffectObserver *)
	?Capability@CMmfGlobalAudioEffect@@QAEIH@Z @ 4 NONAME ; unsigned int CMmfGlobalAudioEffect::Capability(int)
	?CreateCustomInterface@CMmfGlobalAudioEffect@@IAEHVTUid@@@Z @ 5 NONAME ; int CMmfGlobalAudioEffect::CreateCustomInterface(class TUid)
	?CustomInterface@CMmfGlobalAudioEffect@@IAEPAXVTUid@@@Z @ 6 NONAME ; void * CMmfGlobalAudioEffect::CustomInterface(class TUid)
	?ExtractValuesL@CMmfGlobalAudioEffect@@QAEXAAVTDes8@@@Z @ 7 NONAME ; void CMmfGlobalAudioEffect::ExtractValuesL(class TDes8 &)
	?IsActive@CMmfGlobalAudioEffect@@QBEHXZ @ 8 NONAME ; int CMmfGlobalAudioEffect::IsActive(void) const
	?IsEnabled@CMmfGlobalAudioEffect@@QBEHXZ @ 9 NONAME ; int CMmfGlobalAudioEffect::IsEnabled(void) const
	?KnownPresetsL@CMmfGlobalAudioEffect@@QAEPAVMMmfGlobalAudioPresetList@@XZ @ 10 NONAME ; class MMmfGlobalAudioPresetList * CMmfGlobalAudioEffect::KnownPresetsL(void)
	?RequestNotificationL@CMmfGlobalAudioEffect@@QAEXVTUid@@@Z @ 11 NONAME ; void CMmfGlobalAudioEffect::RequestNotificationL(class TUid)
	?SetByValuesL@CMmfGlobalAudioEffect@@QAEXABVTDesC8@@@Z @ 12 NONAME ; void CMmfGlobalAudioEffect::SetByValuesL(class TDesC8 const &)
	?SetEnabledL@CMmfGlobalAudioEffect@@QAEXH@Z @ 13 NONAME ; void CMmfGlobalAudioEffect::SetEnabledL(int)
	?SetSettingsByDesL@CMmfGlobalAudioEffect@@QAEXABVTDesC8@@@Z @ 14 NONAME ; void CMmfGlobalAudioEffect::SetSettingsByDesL(class TDesC8 const &)
	?SetSettingsByUidL@CMmfGlobalAudioEffect@@QAEXVTUid@@@Z @ 15 NONAME ; void CMmfGlobalAudioEffect::SetSettingsByUidL(class TUid)
	?SettingsByDesL@CMmfGlobalAudioEffect@@QBEPAVHBufC8@@XZ @ 16 NONAME ; class HBufC8 * CMmfGlobalAudioEffect::SettingsByDesL(void) const
	?SettingsByUidL@CMmfGlobalAudioEffect@@QBE?AVTUid@@XZ @ 17 NONAME ; class TUid CMmfGlobalAudioEffect::SettingsByUidL(void) const

